package com.sb.support;

import java.beans.*;

import com.streambase.sb.operator.Operator;
import com.streambase.sb.operator.parameter.*;

/**
 * A BeanInfo class controls what properties are exposed, add 
 * metadata about properties (such as which properties are optional), and access 
 * special types of properties that can't be automatically derived via reflection. 
 * If a BeanInfo class is present, only the properties explicitly declared in
 * this class will be exposed by StreamBase.
 */
public class TibbrOutBeanInfo extends SBSimpleBeanInfo {

	/*
	 * The order of properties below determines the order they are displayed within
	 * the StreamBase Studio property view. 
	 */
	public SBPropertyDescriptor[] getPropertyDescriptorsChecked()
			throws IntrospectionException {
		SBPropertyDescriptor[] p = {
				new SBPropertyDescriptor("TibURL", TibbrOut.class).displayName(
						"Tibbr URL").description("The top level URL of a Tibbr instance"),
				new SBPropertyDescriptor("user", TibbrOut.class).displayName(
						"User Name").description("Your username"),
				new SBPropertyDescriptor("password", TibbrOut.class).setUIHints(UIHints.create().setMaskStringDisplay(true))
						.displayName("Password").description("Your password. Use enciphered operator parameters to avoid storing this password in plain-text."),
				new JavaEnumPropertyDescriptor<Operator.LogLevel>("logLevel", TibbrOut.class, Operator.LogLevel.class)
						.displayName("Log level")
						.description("Sets the log level used by the adapter. This setting operates independently of the top-level StreamBase log level value.")
						.optional(),
		 };

		return p;
	}

}
